/****************************************************************

file settings.h

Example Code searching for solutions of Sir Peter Swinnerton-Dyer's
Diophantine equation. An implementation of the hashing algorithm
developed by the authors.

Copyright (C) 2006 A.-S. Elsenhans and J. Jahnel

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

Address of the authors

	A.-S. Elsenhans/ J. Jahnel
	Math. Institut der Universitaet
	Bunsenstrasze 3--5
	D-37073 Goettingen
        Germany

WWW     http://www.uni-math.gwdg.de/jahnel

*****************************************************************/


#define SUCHWEITE     100000000L
/* The program searches for solutions such that x, y, z and w are
   below this limit. */

#define HASH_BREITE          27L
/* The size of the hash table is 2**HASH_BREITE.
   To choose more than 28 is likely to be inefficient (even if you
   have that much memory) as the last four binary digits of
       z**4 + 4 w**4    (or z**4 - x**4, respectively)
   are not random. */

#define PUFFER_BITS          10L
/* Number of bits used for pre-sorting into several buffers.
   The same buffers are used for reading and writing.
   Must be < HASH_BREITE. */

#define PAGE_PRIME1       80039L /* For Case 1. */
#define PAGE_PRIME2      200003L /* For Case 2. */
/* Must be primes 3 modulo 4 in order to ensure that the fourth
   roots modulo PAGE_PRIMEi are unique up to sign.

   We assume that 1250 * PAGE_PRIMEi > SUCHWEITE.

   One has:
       Number of entries in the hash table
     = SUCHWEITE**2 / (2731.56475 * PAGE_PRIME)    (in Case 1)
     = SUCHWEITE**2 / (781.25 * PAGE_PRIME)        (in Case 2)
   for most of the residue classes.

   If this number is > 2**HASH_BREITE then the program will NOT work.
   It seems to work best for 0.3..0.6 * 2**HASH_BREITE. */
